pub struct PublishOpts {
pub package: Option<(PackageRef, Version)>,
pub registry: Option<Registry>,
pub dry_run: bool,
pub skip_semver_check: bool,
}Expand description
Additional options for publishing a package.
Fields
package: Option<(PackageRef, Version)>Override the package name and version to publish with.
registry: Option<Registry>Override the registry to publish to.
dry_run: boolIf true, resolve the package, version, and registry but do not call the backend to publish.
skip_semver_check: boolDisable semver compatibility verification.